'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _mixins = require('../../util/mixins');

var _mixins2 = _interopRequireDefault(_mixins);

var _props = require('./mixins/props');

var _props2 = _interopRequireDefault(_props);

var _path = require('./components/path');

var _path2 = _interopRequireDefault(_path);

var _text = require('./components/text');

var _text2 = _interopRequireDefault(_text);

var _gradient = require('./components/gradient');

var _gradient2 = _interopRequireDefault(_gradient);

var _core = require('./helpers/core');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = (0, _mixins2.default)(_props2.default).extend({
    name: 'trend',
    data: function data() {
        return {
            lastLength: 0
        };
    },
    watch: {
        data: {
            immediate: true,
            handler: function handler() {
                var _this = this;

                this.$nextTick(function () {
                    if (!_this.autoDraw) {
                        return;
                    }
                    var path = _this.$refs.path.$el;
                    var length = path.getTotalLength();
                    path.style.transition = 'none';
                    path.style.strokeDasharray = length + ' ' + length;
                    path.style.strokeDashoffset = Math.abs(length - (_this.lastLength || 0)).toString();
                    path.getBoundingClientRect();
                    path.style.transition = 'stroke-dashoffset ' + _this.autoDrawDuration + 'ms ' + _this.autoDrawEasing;
                    path.style.strokeDashoffset = '0';
                    _this.lastLength = length;
                });
            }
        }
    },
    render: function render(h) {
        if (!this.data || this.data.length < 2) return undefined;
        var width = this.width,
            height = this.height,
            padding = this.padding;

        var viewWidth = width || 300;
        var viewHeight = height || 75;
        var boundary = {
            minX: padding,
            minY: padding,
            maxX: viewWidth - padding,
            maxY: viewHeight - padding
        };
        var props = this.$props;
        props.boundary = boundary;
        props.id = 'sparkline-trend-' + this._uid;
        props.points = (0, _core.genPoints)(this.data, boundary);
        return h('svg', {
            attrs: {
                'stroke-width': this.lineWidth || 1,
                width: width || '100%',
                height: height || '25%',
                viewBox: '0 0 ' + viewWidth + ' ' + viewHeight
            }
        }, [h(_gradient2.default, { props: props }), this.showLabel ? h(_text2.default, { props: props }) : undefined, h(_path2.default, {
            props: props,
            ref: 'path'
        })]);
    }
});
//# sourceMappingURL=Trend.js.map