import mixins from '../../util/mixins';
import props from './mixins/props';
import Rect from './components/rect';
import Text from './components/text';
import Gradient from './components/gradient';
import { genPoints } from './helpers/core';
export default mixins(props).extend({
    name: 'bar',
    props: {
        autoDrawDuration: {
            type: Number,
            default: 500
        }
    },
    render: function render(h) {
        if (!this.data || this.data.length < 2) return undefined;
        var width = this.width,
            height = this.height,
            padding = this.padding,
            lineWidth = this.lineWidth;

        var viewWidth = width || 300;
        var viewHeight = height || 75;
        var boundary = {
            minX: padding,
            minY: padding,
            maxX: viewWidth - padding,
            maxY: viewHeight - padding
        };
        var props = this.$props;
        props.points = genPoints(this.data, boundary);
        var totalWidth = boundary.maxX / (props.points.length - 1);
        props.boundary = boundary;
        props.id = 'sparkline-bar-' + this._uid;
        props.lineWidth = lineWidth || totalWidth - (padding || 5);
        props.offsetX = (totalWidth - props.lineWidth) / 2;
        return h('svg', {
            attrs: {
                width: width || '100%',
                height: height || '25%',
                viewBox: '0 0 ' + viewWidth + ' ' + viewHeight
            }
        }, [h(Gradient, { props: props }), h(Rect, { props: props }), this.showLabel ? h(Text, { props: props }) : undefined, h('g', {
            attrs: {
                transform: 'scale(1,-1) translate(0,-' + boundary.maxY + ')',
                'clip-path': 'url(#' + props.id + '-clip)',
                fill: 'url(#' + props.id + ')'
            }
        }, [h('rect', {
            attrs: {
                x: 0,
                y: 0,
                width: viewWidth,
                height: viewHeight
            }
        })])]);
    }
});
//# sourceMappingURL=Bar.js.map