import mixins from '../../util/mixins';
import props from './mixins/props';
import Path from './components/path';
import Text from './components/text';
import Gradient from './components/gradient';
import { genPoints } from './helpers/core';
export default mixins(props).extend({
    name: 'trend',
    data: function data() {
        return {
            lastLength: 0
        };
    },
    watch: {
        data: {
            immediate: true,
            handler: function handler() {
                var _this = this;

                this.$nextTick(function () {
                    if (!_this.autoDraw) {
                        return;
                    }
                    var path = _this.$refs.path.$el;
                    var length = path.getTotalLength();
                    path.style.transition = 'none';
                    path.style.strokeDasharray = length + ' ' + length;
                    path.style.strokeDashoffset = Math.abs(length - (_this.lastLength || 0)).toString();
                    path.getBoundingClientRect();
                    path.style.transition = 'stroke-dashoffset ' + _this.autoDrawDuration + 'ms ' + _this.autoDrawEasing;
                    path.style.strokeDashoffset = '0';
                    _this.lastLength = length;
                });
            }
        }
    },
    render: function render(h) {
        if (!this.data || this.data.length < 2) return undefined;
        var width = this.width,
            height = this.height,
            padding = this.padding;

        var viewWidth = width || 300;
        var viewHeight = height || 75;
        var boundary = {
            minX: padding,
            minY: padding,
            maxX: viewWidth - padding,
            maxY: viewHeight - padding
        };
        var props = this.$props;
        props.boundary = boundary;
        props.id = 'sparkline-trend-' + this._uid;
        props.points = genPoints(this.data, boundary);
        return h('svg', {
            attrs: {
                'stroke-width': this.lineWidth || 1,
                width: width || '100%',
                height: height || '25%',
                viewBox: '0 0 ' + viewWidth + ' ' + viewHeight
            }
        }, [h(Gradient, { props: props }), this.showLabel ? h(Text, { props: props }) : undefined, h(Path, {
            props: props,
            ref: 'path'
        })]);
    }
});
//# sourceMappingURL=Trend.js.map